#include <p33fj256gp710.h>
#include "PCM_X2.h"

#define _FAR __attribute__(( far))
#define Nop() {__asm__ volatile ("nop");}

volatile int sample[8]; 	//holds samples for ONE data frame
volatile int slot_counter;	//keep tracks of unload slot currently being read
volatile int unload_counter;	
volatile int count;

//-------------------------------------------INTERRUPT ROUTINES----------------------------------------
void _ISRFAST _IC1Interrupt( void)
{
	//used to detect sync pulse
	//capture every rising edge

	count = 32;	//used for delay

	//delay

	while (count > 0)
		count--;
	//_RA1 = 0;
	SPI1BUF = 0b0111010101011101; //dummy write to activate SPI unit first time [slot 1]	

	for ( slot_counter=0; slot_counter<8; slot_counter = slot_counter + 1)
	{
			//_RA1 = 1;
		while( SPI1STATbits.SPITBF);
			{   //wait for transmit buffer to become available
			    //Data to be transmitted can be written to SPIxBUF by the user software at any time as long
				//as the SPIxTBF (SPIxSTAT<1>) bit is clear. The write can occur while SPIxSR is shifting
				//out the previously written data, allowing continuous transmission.	
			}
		  //_RA1 = 0;
			SPI1BUF = slot_counter  ; //dummy write to activate SPI
	       //Nop();
		//	_RA1 = 1;

		while( !SPI1STATbits.SPIRBF);
			{//wait for recieve to complete
			//_RA1 = 0;
			//_RA1 = 1;
			//_RA1 = 0;
			}
			//_RA1 = 0;
			//_RA1 = 1;
			//_RA1 = 0;
			sample[slot_counter] = SPI1BUF; //read the recieved sample
	
	}

    _IC1IF = 0; // clear the interrupt flag

} // IC1Interrupt

void _ISRFAST _SPI1Interrupt( void)
{
	sample[unload_counter] = SPI1BUF; //read the recieved sample
	
	unload_counter++;

	if (unload_counter == 8)
		unload_counter = 0;

	_SPI1IF = 0;	// clear the interrupt flag

}//SP1Interrupt

//-------------------------------------------END OF INTERRUPT ROUTINES----------------------------------------
//------------------------------------------------------------------------------------------------------------
//---------------------------------------START OF INITIALIZATION ROUTINES-------------------------------------
void initSys( void)
{
	//Set Oscillator Configuration for 40MIPS
	OSCCON = 0x0300;			//
	CLKDIV = 0x0000;			//
	PLLFBD = 0x0026;			//
	
    // set the priority levels
	_IC1IP = 4;					//DEFAULT

	//setup IC Modules                                    ___
	IC1CON = 0x0003;			//capture every rising __|    edge

	// init Interrupts, clear the flag
    _IC1IF = 0; _IC1IE = 1;	
    	
	// init the processor priority level
	_IPL = 0;					// this is the default value anyway
    
    // init PORTS
	_TRISD8 = 1;				//make IC1 = RD8 pin an input
	_TRISA1 = 0;

	slot_counter = 0;
	unload_counter = 0;

} // initSys

void initSPI( void)
{
	SPI1BUF = 0x0000;		//clear SPI buffer

	_SPI1IF = 0;			//clear SPI interrupt flag
	_SPI1IE = 0;    		//enable interrupt
	_SPI1IP = 4;    		//set SPI priority 		

	SPI1CON1 = 0b1010000111101;		//
	SPI1CON2 = 0x0000;      // 

	_SPIROV = 0;			//clear Receive Overflow Flag bit

    SPI1STAT = 0x8000;      // enable SPI port

}//initSPI

//---------------------------------------END OF INITIALIZATION ROUTINES---------------------------------------
//------------------------------------------------------------------------------------------------------------
//-------------------------------------------------- MAIN ----------------------------------------------------
int main()
{

    // initializations
    initSys();    	// initialize basic system
	initSPI();		// initialize SPI
	while(1)
	{
		//main loop
	}

	return 0;
	
} // main
//------------------------------------------------------------------------------------------------------------
